@@ -1,5 +1,3 @@
-context("sims-simulate")
-
 test_that("test inputs", {
   expect_error(sims_simulate(1),
     "`code` must be a string [(]non-missing character scalar[)].",
@@ -29,6 +27,8 @@ test_that("test inputs", {
 })
 
 test_that("test nodes not already defined", {
+  skip_if_not_installed("rjags")
+  
   expect_error(
     sims_simulate("a ~ dunif(1)", nlist(a = 1)),
     "^The following variable nodes are defined in constants: 'a'[.]$"
@@ -36,6 +36,8 @@ test_that("test nodes not already defined", {
 })
 
 test_that("test match at least one node", {
+  skip_if_not_installed("rjags")
+  
   expect_error(
     sims_simulate("a ~ dunif(1)", list(x = 1),
       monitor = "b",
@@ -94,6 +96,8 @@ test_that("test match at least one node", {
 })
 
 test_that("not in model or data block", {
+  skip_if_not_installed("rjags")
+  
   expect_error(
     sims_simulate("model {a ~ dunif(1)}", nlist(x = 1), monitor = "a"),
     "^JAGS code must not be in a data or model block."
@@ -105,22 +109,24 @@ test_that("not in model or data block", {
 })
 
 test_that("generates data with replicability", {
-  set.seed(1)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.749735354622374))
   )
-  set.seed(1)
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.749735354622374))
   )
-  set.seed(-1)
+  withr::local_seed(-1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.315564033523335))
   )
-  set.seed(1)
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.749735354622374))
@@ -128,7 +134,9 @@ test_that("generates data with replicability", {
 })
 
 test_that("generates data with replicability if repeated calls", {
-  set.seed(1)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.749735354622374))
@@ -141,7 +149,7 @@ test_that("generates data with replicability if repeated calls", {
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.534957256848294))
   )
-  set.seed(1)
+  withr::local_seed(1)
   runif(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
@@ -151,7 +159,7 @@ test_that("generates data with replicability if repeated calls", {
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.534957256848294))
   )
-  set.seed(1)
+  withr::local_seed(1)
   runif(2)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
@@ -160,15 +168,17 @@ test_that("generates data with replicability if repeated calls", {
 })
 
 test_that("save", {
+  skip_if_not_installed("rjags")
+  
   tempdir <- file.path(tempdir(), "sims")
   unlink(tempdir, recursive = TRUE)
 
-  set.seed(1)
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.749735354622374))
   )
-  set.seed(1)
+  withr::local_seed(1)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)", save = NA, path = tempdir),
     nlist::nlists(nlist(a = 0.749735354622374))
@@ -181,7 +191,7 @@ test_that("save", {
     readRDS(file.path(tempdir, "data0000001.rds")),
     nlist(a = 0.749735354622374)
   )
-  set.seed(1)
+  withr::local_seed(1)
   unlink(tempdir, recursive = TRUE)
   expect_true(sims_simulate("a ~ dunif(0,1)", save = TRUE, path = tempdir))
   expect_identical(
@@ -195,6 +205,8 @@ test_that("save", {
 })
 
 test_that("gets deterministic nodes", {
+  skip_if_not_installed("rjags")
+  
   generative_model <- "
 for (i in 1:length(year)) {
   cc[i] ~ dpois(lambda[i])
@@ -208,7 +220,7 @@ rand ~ dnorm(0,1)
 
   constants <- nlist(year = 1:5)
 
-  set.seed(2)
+  withr::local_seed(2)
   expect_equal(
     sims_simulate(generative_model,
       constants = constants,
@@ -234,7 +246,7 @@ test_that("gets deterministic nodes with R code", {
 
   constants <- nlist(year = 1:5)
 
-  set.seed(2)
+  withr::local_seed(2)
   expect_equal(
     sims_simulate(generative_model,
       constants = constants,
@@ -252,7 +264,9 @@ test_that("gets deterministic nodes with R code", {
 })
 
 test_that("nsims can take numeric", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.342673102637473))
@@ -260,7 +274,9 @@ test_that("nsims can take numeric", {
 })
 
 test_that("nsims > 1", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)", nsims = 2L),
     nlist::nlists(
@@ -268,7 +284,7 @@ test_that("nsims > 1", {
       nlist(a = 0.0584777028255878)
     )
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)", nsims = 2L),
     nlist::nlists(
@@ -279,22 +295,24 @@ test_that("nsims > 1", {
 })
 
 test_that("write replicable", {
+  skip_if_not_installed("rjags")
+  
   tempdir <- file.path(tempdir(), "sims")
   unlink(tempdir, recursive = TRUE)
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)", path = tempdir, save = TRUE))
   expect_error(
     sims_simulate("a ~ dunif(0,1)", path = tempdir, save = TRUE),
     "must not already exist"
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
   ))
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -446,10 +464,12 @@ test_that("write replicable", {
 })
 
 test_that("write replicable > 1", {
+  skip_if_not_installed("rjags")
+  
   tempdir <- file.path(tempdir(), "sims")
   unlink(tempdir, recursive = TRUE)
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L,
     path = tempdir, save = TRUE
@@ -462,12 +482,12 @@ test_that("write replicable > 1", {
     readRDS(file.path(tempdir, "data0000002.rds")),
     nlist(a = 0.0584777028255878)
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_error(
     sims_simulate("a ~ dunif(0,1)", nsims = 2L, path = tempdir, save = TRUE),
     "must not already exist"
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L, path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -480,7 +500,7 @@ test_that("write replicable > 1", {
     readRDS(file.path(tempdir, "data0000002.rds")),
     nlist(a = 0.0584777028255878)
   )
-  set.seed(100)
+  withr::local_seed(100)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -490,7 +510,7 @@ test_that("write replicable > 1", {
     nlist(a = 0.771283060089858)
   )
   expect_identical(list.files(tempdir), "data0000001.rds")
-  set.seed(100)
+  withr::local_seed(100)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L, path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -503,7 +523,7 @@ test_that("write replicable > 1", {
     readRDS(file.path(tempdir, "data0000002.rds")),
     nlist(a = 0.558316438218761)
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -515,7 +535,9 @@ test_that("write replicable > 1", {
 })
 
 test_that("monitor", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.342673102637473))
@@ -558,6 +580,8 @@ test_that("monitor", {
 })
 
 test_that("append constants", {
+  skip_if_not_installed("rjags")
+  
   expect_error(
     sims_simulate("ab ~ dunif(0,1)",
       monitor = c("a", "a"),
@@ -578,23 +602,23 @@ test_that("append constants", {
 })
 
 test_that("parallel with registered", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.342673102637473))
   )
 
-  options(mc.cores = 2)
-  future::plan(future::multisession)
-  teardown(future::plan(future::sequential))
-
-  set.seed(101)
+  use_local_plan(future::multisession)
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)"),
     nlist::nlists(nlist(a = 0.342673102637473))
   )
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)", nsims = 2),
     nlist::nlists(
@@ -605,10 +629,12 @@ test_that("parallel with registered", {
 })
 
 test_that("parallel with registered files", {
+  skip_if_not_installed("rjags")
+  
   tempdir <- file.path(tempdir(), "sims")
   unlink(tempdir, recursive = TRUE)
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L,
     path = tempdir, save = TRUE
@@ -623,7 +649,7 @@ test_that("parallel with registered files", {
   )
 
   expect_identical(list.files(tempdir), c("data0000001.rds", "data0000002.rds"))
-  set.seed(100)
+  withr::local_seed(100)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -634,11 +660,9 @@ test_that("parallel with registered files", {
     nlist(a = 0.771283060089858)
   )
 
-  options(mc.cores = 2)
-  future::plan(future::multisession)
-  teardown(future::plan(future::sequential))
-
-  set.seed(101)
+  use_local_plan(future::multisession)
+  
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L, path = tempdir, save = TRUE,
     exists = TRUE, ask = FALSE, silent = TRUE
@@ -656,10 +680,12 @@ test_that("parallel with registered files", {
 })
 
 test_that("write existing with random file not touched", {
+  skip_if_not_installed("rjags")
+  
   tempdir <- file.path(tempdir(), "sims")
   unlink(tempdir, recursive = TRUE)
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     nsims = 2L,
     path = tempdir, save = TRUE
@@ -702,7 +728,9 @@ test_that("write existing with random file not touched", {
 })
 
 test_that("names with dots and underscores", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x.y ~ dunif(0,1)", nsims = 2L),
     nlist::nlists(
@@ -710,7 +738,7 @@ test_that("names with dots and underscores", {
       nlist(x.y = 0.0584777028255878)
     )
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x_y ~ dunif(0,1)", nsims = 2L),
     nlist::nlists(
@@ -721,19 +749,21 @@ test_that("names with dots and underscores", {
 })
 
 test_that("stochastic nodes", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = NA, latent = NA),
     nlist::nlists(nlist(x = 0.342673102637473, y = 0.342673102637473))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = TRUE, latent = NA),
     nlist::nlists(nlist(x = 0.342673102637473))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = FALSE, latent = NA),
@@ -742,19 +772,21 @@ test_that("stochastic nodes", {
 })
 
 test_that("latent nodes", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = NA, latent = NA),
     nlist::nlists(nlist(x = 0.342673102637473, y = 0.342673102637473))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = NA, latent = FALSE),
     nlist::nlists(nlist(y = 0.342673102637473))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                              y <- x", stochastic = NA, latent = TRUE),
@@ -763,7 +795,9 @@ test_that("latent nodes", {
 })
 
 test_that("latent, stochastic nodes", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -774,7 +808,7 @@ test_that("latent, stochastic nodes", {
       y = 2, y2 = 0.912021637658974
     ))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -782,7 +816,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = TRUE, latent = NA),
     nlist::nlists(nlist(x = 0.574752916346771, x2 = 0.912021637658974))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -790,7 +824,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = FALSE, latent = NA),
     nlist::nlists(nlist(y = 2, y2 = 0.912021637658974))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -798,7 +832,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = NA, latent = FALSE),
     nlist::nlists(nlist(x = 0.574752916346771, y2 = 0.912021637658974))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -807,7 +841,7 @@ test_that("latent, stochastic nodes", {
     nlist::nlists(nlist(x2 = 0.912021637658974, y = 2))
   )
   # note the nodes monitored affects the random draws
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -815,7 +849,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = TRUE, latent = FALSE),
     nlist::nlists(nlist(x = 0.342673102637473))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -823,7 +857,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = TRUE, latent = TRUE),
     nlist::nlists(nlist(x2 = 0.912021637658974))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -831,7 +865,7 @@ test_that("latent, stochastic nodes", {
                               y2 <- x2", stochastic = FALSE, latent = FALSE),
     nlist::nlists(nlist(y2 = 0.912021637658974))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x2 ~ dnorm(y,1)
@@ -842,7 +876,9 @@ test_that("latent, stochastic nodes", {
 })
 
 test_that("latent, stochastic nodes with dots on end", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("x ~ dunif(0,1)
                               x. ~ dnorm(y,1)
@@ -853,7 +889,9 @@ test_that("latent, stochastic nodes with dots on end", {
 })
 
 test_that("handles =", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_error(
     sims_simulate("Y = beta + epsilon
       beta ~ dnorm(0,1)
@@ -861,7 +899,7 @@ test_that("handles =", {
     "^JAGS code must include at least one observed stochastic variable node[.]$"
   )
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("Y = beta + epsilon
       beta ~ dnorm(0,1)
@@ -869,7 +907,7 @@ test_that("handles =", {
     nlist::nlists(nlist(beta = 0.51630333187765, epsilon = -1.08797836234103))
   )
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("Y = beta + epsilon
       beta ~ dnorm(0,1)
@@ -882,7 +920,9 @@ test_that("handles =", {
 })
 
 test_that("with [] latent variables", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dt(theta[1],theta[2],df)",
       parameters = nlist(df = 1, theta = c(1, 1))
@@ -892,14 +932,16 @@ test_that("with [] latent variables", {
 })
 
 test_that("strips comments before", {
-  set.seed(101)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("b ~ dnorm(a, 1)
                              # a ~ dunif(1)", parameters = list(a = 1)),
     nlist::nlists(nlist(b = -0.0879783623410262))
   )
 
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a ~ dunif(0,1)
                              # x <- a"),
@@ -908,17 +950,17 @@ test_that("strips comments before", {
 })
 
 test_that("with R code", {
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = NA),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = NA),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(100)
+  withr::local_seed(100)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = NA),
     nlist::nlists(nlist(a = 0.959129601367507))
@@ -983,7 +1025,7 @@ test_that("with R code", {
 
 
 test_that("with R code in parallel", {
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", nsims = 2, ),
     nlist::nlists(
@@ -992,11 +1034,9 @@ test_that("with R code in parallel", {
     )
   )
 
-  options(mc.cores = 2)
-  future::plan(future::multisession)
-  teardown(future::plan(future::sequential))
-
-  set.seed(101)
+  use_local_plan(future::multisession)
+  
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", nsims = 2),
     nlist::nlists(
@@ -1007,17 +1047,17 @@ test_that("with R code in parallel", {
 })
 
 test_that("with R code and single stochastic node", {
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = TRUE),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = NA),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)", stochastic = FALSE,
                   rdists = character(0)),
@@ -1033,26 +1073,26 @@ test_that("with R code and single stochastic node", {
 })
 
 test_that("with R code and stochastic and deterministic nodes", {
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              b <- 1", stochastic = TRUE),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              b <- 1", stochastic = NA),
     nlist::nlists(nlist(a = 0.637362094961879, b = 1))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              b <- 1",
                   stochastic = FALSE, rdists = character(0)),
     nlist::nlists(nlist(a = 0.637362094961879, b = 1))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              b <- 1", stochastic = FALSE),
@@ -1061,21 +1101,21 @@ test_that("with R code and stochastic and deterministic nodes", {
 })
 
 test_that("with R code & stochastic & deterministic nodes & different rdist", {
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              runif <- 1
                              b <- runif", stochastic = TRUE),
     nlist::nlists(nlist(a = 0.637362094961879))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              runif <- 1
                              b <- runif", stochastic = NA, latent = FALSE),
     nlist::nlists(nlist(a = 0.637362094961879, b = 1))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              runif <- 1
@@ -1083,7 +1123,7 @@ test_that("with R code & stochastic & deterministic nodes & different rdist", {
                   latent = FALSE, rdists = character(0)),
     nlist::nlists(nlist(a = 0.637362094961879, b = 1))
   )
-  set.seed(101)
+  withr::local_seed(101)
   expect_equal(
     sims_simulate("a <- runif(1, 0, 1)
                              runif <- 1
@@ -1093,16 +1133,15 @@ test_that("with R code & stochastic & deterministic nodes & different rdist", {
 })
 
 test_that("save parallel", {
-  tempdir <- file.path(tempdir(), "sims")
+  skip_if_not_installed("rjags")
+  
+  tempdir <- withr::local_tempdir()
   unlink(tempdir, recursive = TRUE)
-  teardown(unlink(tempdir, recursive = TRUE))
 
-  set.seed(1)
-
-  options(mc.cores = 2)
-  future::plan(future::multisession)
-  teardown(future::plan(future::sequential))
+  withr::local_seed(1)
 
+  use_local_plan(future::multisession)
+  
   expect_true(sims_simulate("a ~ dunif(0,1)",
     save = TRUE, exists = FALSE,
     path = tempdir,
@@ -1116,7 +1155,9 @@ test_that("save parallel", {
 })
 
 test_that("simulate array", {
-  set.seed(10)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(10)
   sims <- sims::sims_simulate("for(i in 1:2) {
   M[i,1] ~ dnorm(0,1)
   M[i,2] <- 2}")
@@ -1127,7 +1168,9 @@ test_that("simulate array", {
 })
 
 test_that("progress", {
-  set.seed(1)
+  skip_if_not_installed("rjags")
+  
+  withr::local_seed(1)
   progressr::with_progress(x <- sims_simulate("a ~ dunif(0,1)", nsims = 1L))
   expect_equal(
     x,
@@ -1139,16 +1182,14 @@ test_that("progress", {
 })
 
 test_that("save getwd", {
+  skip_if_not_installed("rjags")
+  
   skip("only test getwd at console")
-  tempdir <- file.path(tempdir(), "sims")
-  unlink(tempdir, recursive = TRUE)
-  teardown(unlink(tempdir, recursive = TRUE))
+  tempdir <- withr::local_tempdir()
 
-  set.seed(1)
+  withr::local_seed(1)
 
-  dir.create(tempdir)
-  wd <- setwd(tempdir)
-  on.exit(setwd(wd))
+  withr::local_dir(tempdir)
   expect_true(sims_simulate("a ~ dunif(0,1)",
     save = TRUE, exists = NA,
     ask = FALSE
